import { Ask, Bid, BidShares, SpaceData } from "./types";
import { BigNumber, BigNumberish } from "@ethersproject/bignumber";
import { ContractTransaction } from "@ethersproject/contracts";
import { Provider } from "@ethersproject/providers";
import { Signer } from "@ethersproject/abstract-signer";
import { SpaceExchange, Space } from "@motif-foundation/asset/dist/typechain";
export declare class MotifSpace {
    chainId: number;
    spaceAddress: string;
    spaceExchangeAddress: string;
    signerOrProvider: Signer | Provider;
    space: Space;
    spaceExchange: SpaceExchange;
    readOnly: boolean;
    constructor(signerOrProvider: Signer | Provider, chainId: number);
    /*********************
     * Space Read Methods
     *********************
     */
    fetchContentHash(spaceId: BigNumberish): Promise<string>;
    fetchMetadataHash(spaceId: BigNumberish): Promise<string>;
    fetchContentURI(spaceId: BigNumberish): Promise<string>;
    fetchMetadataURI(spaceId: BigNumberish): Promise<string>;
    fetchIsPublic(spaceId: BigNumberish): Promise<boolean>;
    fetchLands(spaceId: BigNumberish): Promise<Array<BigNumberish>>;
    fetchCreator(spaceId: BigNumberish): Promise<string>;
    fetchCurrentBidShares(spaceId: BigNumberish): Promise<BidShares>;
    fetchCurrentAsk(spaceId: BigNumberish): Promise<Ask>;
    fetchCurrentBidForBidder(spaceId: BigNumberish, bidder: string): Promise<Bid>;
    fetchPermitNonce(address: string, spaceId: BigNumberish): Promise<BigNumber>;
    fetchMintWithSigNonce(address: string): Promise<BigNumber>;
    updateContentURI(spaceId: BigNumberish, tokenURI: string): Promise<ContractTransaction>;
    updateMetadataURI(spaceId: BigNumberish, metadataURI: string): Promise<ContractTransaction>;
    mint(spaceData: SpaceData, bidShares: BidShares): Promise<ContractTransaction>;
    setAsk(spaceId: BigNumberish, ask: Ask): Promise<ContractTransaction>;
    setBid(spaceId: BigNumberish, bid: Bid): Promise<ContractTransaction>;
    removeAsk(spaceId: BigNumberish): Promise<ContractTransaction>;
    removeBid(spaceId: BigNumberish): Promise<ContractTransaction>;
    acceptBid(spaceId: BigNumberish, bid: Bid): Promise<ContractTransaction>;
    revokeApproval(spaceId: BigNumberish): Promise<ContractTransaction>;
    burn(spaceId: BigNumberish): Promise<ContractTransaction>;
    fetchBalanceOf(owner: string): Promise<BigNumber>;
    fetchOwnerOf(spaceId: BigNumberish): Promise<string>;
    fetchSpaceOfOwnerByIndex(owner: string, index: BigNumberish): Promise<BigNumber>;
    fetchTotalSpace(): Promise<BigNumber>;
    fetchSpaceByIndex(index: BigNumberish): Promise<BigNumber>;
    fetchApproved(spaceId: BigNumberish): Promise<string>;
    fetchIsApprovedForAll(owner: string, operator: string): Promise<boolean>;
    /***********************
     * ERC-721 Write Methods
     ***********************
     */
    approve(to: string, spaceId: BigNumberish): Promise<ContractTransaction>;
    setApprovalForAll(operator: string, approved: boolean): Promise<ContractTransaction>;
    transferFrom(from: string, to: string, spaceId: BigNumberish): Promise<ContractTransaction>;
    safeTransferFrom(from: string, to: string, spaceId: BigNumberish): Promise<ContractTransaction>;
    /****************
     * Miscellaneous
     * **************
     */
    isValidBid(spaceId: BigNumberish, bid: Bid): Promise<boolean>;
    isValidAsk(spaceId: BigNumberish, ask: Ask): Promise<boolean>;
    isVerifiedSpace(spaceId: BigNumberish, timeout?: number): Promise<boolean>;
    /******************
     * Private Methods
     ******************
     */
    private ensureNotReadOnly;
}
