import { BigNumber, BigNumberish } from '@ethersproject/bignumber';
import { BytesLike } from '@ethersproject/bytes';
/**
 * Internal type to represent a Decimal Value
 */
export declare type DecimalValue = {
    value: BigNumber;
};
/**
 * Motif Item Protocol BidShares
 */
export declare type BidShares = {
    owner: DecimalValue;
    prevOwner: DecimalValue;
    creator: DecimalValue;
};
/**
 * Motif Item Protocol Ask
 */
export declare type Ask = {
    currency: string;
    amount: BigNumberish;
};
/**
 * Motif Item Protocol Bid
 */
export declare type Bid = {
    currency: string;
    amount: BigNumberish;
    bidder: string;
    recipient: string;
    sellOnShare: DecimalValue;
};
/**
 * Motif Item Protocol ItemData
 */
export declare type ItemData = {
    tokenURI: string;
    metadataURI: string;
    contentHash: BytesLike;
    metadataHash: BytesLike;
};
export declare type AvatarData = {
    tokenURI: string;
    metadataURI: string;
    contentHash: BytesLike;
    metadataHash: BytesLike;
};
export declare type SpaceData = {
    tokenURI: string;
    metadataURI: string;
    contentHash: BytesLike;
    metadataHash: BytesLike;
    isPublic: boolean;
    lands: Array<BigNumberish>;
};
export declare type LandData = {
    tokenURI: string;
    metadataURI: string;
    contentHash: BytesLike;
    metadataHash: BytesLike;
    xCoordinate: number;
    yCoordinate: number;
};
/**
 * EIP712 Signature
 */
export declare type EIP712Signature = {
    deadline: BigNumberish;
    v: number;
    r: BytesLike;
    s: BytesLike;
};
/**
 * EIP712 Domain
 */
export declare type EIP712Domain = {
    name: string;
    version: string;
    chainId: number;
    verifyingContract: string;
};
